==> haskell-data-textual-0.3.0.2-75-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-Li7o0oanCSw9SfVmXNovPY
key: data-textual-0.3.0.2-Li7o0oanCSw9SfVmXNovPY
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: a61293a2bc513ba965821f27d7e037f4
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-Li7o0oanCSw9SfVmXNovPY
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    text-latin1-0.3.1-DWrBe0EKJi1CNKTGJ7yOZG
    text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3
    parsers-0.12.9-4GrwhAhZQQXCShRIiRbCUe
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             text-latin1-0.3.1-DWrBe0EKJi1CNKTGJ7yOZG=efb11c720120926c0aa80c52dc28ee57
             text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3=4c306133e10ab2aa2f565b63cd733014
             parsers-0.12.9-4GrwhAhZQQXCShRIiRbCUe=24b350880832a6e1fdf10f92f33138f5
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.2-77-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-EUT8Wtz4Elk5oDCUbqiObR
key: data-textual-0.3.0.2-EUT8Wtz4Elk5oDCUbqiObR
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: cbf374a4fe95e98eae2f5637e180c5e8
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.6.1/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-EUT8Wtz4Elk5oDCUbqiObR
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    parsers-0.12.9-32USTE5qxG7GtQGSzQnxCG text-1.2.3.1
    text-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
    text-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
